diff --git a/asdf.asd b/asdf.asd
index e2c183602d80c7cc85b3a680b4c6663e8b36a8ec..947f8e709995ca9158721867f764a4ce3ac4823b 100644
--- a/asdf.asd
+++ b/asdf.asd
@@ -14,7 +14,7 @@
   :licence "MIT"
   :description "Another System Definition Facility"
   :long-description "ASDF builds Common Lisp software organized into defined systems."
-  :version "2.018.12" ;; to be automatically updated by bin/bump-revision
+  :version "2.018.13" ;; to be automatically updated by bin/bump-revision
   :depends-on ()
   :components
   ((:file "asdf")
diff --git a/asdf.lisp b/asdf.lisp
index 4c4bded603aca4eb72254d18daf0a6d1e324a13f..546b6fb24469342b2a71d5ad53c169bb4006a6c2 100644
--- a/asdf.lisp
+++ b/asdf.lisp
@@ -1,5 +1,5 @@
 ;;; -*- mode: Common-Lisp; Base: 10 ; Syntax: ANSI-Common-Lisp -*-
 ;;; This is ASDF 2.018.12: Another System Definition Facility.
 ;;;
 ;;; Feedback, bug reports, and patches are all welcome:
 ;;; please mail to <asdf-devel@common-lisp.net>.
@@ -107,7 +107,7 @@
          ;; "2.345.6" would be a development version in the official upstream
          ;; "2.345.0.7" would be your seventh local modification of official release 2.345
          ;; "2.345.6.7" would be your seventh local modification of development version 2.345.6
-         (asdf-version "2.018.12")
+         (asdf-version "2.018.13")
          (existing-asdf (find-class 'component nil))
          (existing-version *asdf-version*)
          (already-there (equal asdf-version existing-version)))
@@ -226,7 +226,7 @@
             #:compile-file* #:source-file-type)
            :unintern
            (#:*asdf-revision* #:around #:asdf-method-combination
-            #:split #:make-collector
+            #:split #:make-collector #:do-dep #:do-one-dep
             #:output-files-for-system-and-operation) ; obsolete ASDF-BINARY-LOCATION function
            :export
            (#:defsystem #:oos #:operate #:find-system #:run-shell-command
@@ -1,5 +1,5 @@
 ;;; -*- mode: Common-Lisp; Base: 10 ; Syntax: ANSI-Common-Lisp -*-
-;;; This is ASDF 2.018.12: Another System Definition Facility.
+;;; This is ASDF 2.018.13: Another System Definition Facility.
 ;;;
 ;;; Feedback, bug reports, and patches are all welcome: